@@ -1,5 +1,5 @@
 from looker_loader.models.database import DatabaseField, DatabaseTable
-from looker_loader.models.recipe import LookerMixture, Recipe, CookBook, RecipeFilter, LookerRecipeDimension, LookerRecipeDerivedDimension, LookerMixtureDimension
+from looker_loader.models.recipe import LookerMixture, Recipe, CookBook, RecipeFilter, LookerMixtureDimension
 
 from typing import List, Optional, Union
 import re
@@ -35,30 +35,35 @@ class RecipeMixer:
         """
         Check if a filter is relevant for the given field_name, type, and tags.
         """
-
         return all([
-            not filter.type or filter.type == field.type,
-            not filter.db_type or filter.db_type == field.db_type,
+            not filter.types or field.type in filter.types,
+            not filter.db_types or field.db_type in filter.db_types,
             not filter.regex_include or re.search(filter.regex_include, field.name),
             not filter.regex_exclude or not re.search(filter.regex_exclude, field.name),
             not filter.tags or any(tag in filter.tags for tag in field.tags),
             not filter.fields_include or field.name in filter.fields_include,
             not filter.fields_exclude or field.name not in filter.fields_exclude,
             not filter.field_order or field.order in filter.field_order,
+            not filter.is_nested or field.is_nested == filter.is_nested,
+            not filter.depth or field.depth in filter.depth,
+            not filter.table_regex_include or (field.table_name and re.search(filter.table_regex_include, field.table_name)),
+            not filter.table_regex_exclude or (field.table_name and not re.search(filter.table_regex_exclude, field.table_name)),
         ])
 
     def create_mixture(
-        self, field: DatabaseField
+        self, field: DatabaseField, recipe_list: Optional[List[str]] = None
     ) -> Optional[Recipe]:
         """
         Combine relevant recipes from cookbook based on field_name, type, and tags.
         """
         if not self.cookbook.recipes:
             raise Exception("No recipes found in cookbook")
-
+        
         relevant_recipes = [
-            recipe.dimension.model_dump() for recipe in self.cookbook.recipes
+            recipe.dimension.model_dump()
+            for recipe in self.cookbook.recipes
             if self.is_filter_relevant(recipe.filters, field)
+            and (not recipe_list or recipe.name in recipe_list)
         ]
 
         if self.lexicanum:
@@ -169,7 +174,7 @@ class RecipeMixer:
         """Create and apply a mixture to a column, returning the applied mixture and its variants."""
         
         if not config.unstyled:
-            mixture = self.create_mixture(column)
+                mixture = self.create_mixture(column, config.only_apply_recipe)
         else:
             mixture = None
 
@@ -206,37 +211,6 @@ class RecipeMixer:
             result.append(v)
         return result
 
-    # def lexicalize(self, mixture: LookerMixture, lex) -> LookerMixture:
-    #     """
-    #     Apply lexical rules to the mixture.
-    #     """
-    #     if not lex:
-    #         logging.error("Lexical rules are not provided")
-    #         raise Exception("Lexical rules are not provided")
-
-    #     if not mixture.fields:
-    #         logging.error("No fields found in mixture")
-    #         raise Exception("No fields found in mixture")
-        
-    #     fields = []
-    #     for field in mixture.fields:
-    #         if field.name in lex.root:
-    #             logging.debug(f"Applying lexical rules to field: {field.name}")
-    #             updated_field = self._combine_dicts(
-    #                 field.model_dump(), lex.root[field.name].model_dump(),
-    #                 conflict_resolution="last"
-    #             )
-    #             fields.append(updated_field)
-    #         else:
-    #             fields.append(field.model_dump())
-
-    #     model = LookerMixture(**{
-    #         "name": mixture.name,
-    #         "sql_table_name": mixture.sql_table_name,
-    #         "fields": fields,
-    #     })
-    #     return model
-
     def mixturize(self, table: DatabaseTable, config) -> LookerMixture:
         """
         Search for and apply recipes to the table.
